## 指数日线行情

接口：index_daily，可以通过数据工具调试和查看数据。

描述：获取指数每日行情，还可以通过bar接口获取。由于服务器压力，目前规则是单次调取最多取8000行记录，可以设置start和end日期补全。指数行情也可以通过通用行情接口获取数据．

权限：用户累积2000积分可调取，5000积分以上频次相对较高。本接口不包括申万行情数据，申万等行业指数行情需5000积分以上，具体请参阅积分获取办法 







输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 指数代码，来源指数基础信息接口 |
| trade_date | str | N | 交易日期 （日期格式：YYYYMMDD，下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |







输出参数

| 名称 | 类型 | 描述 |
| --- | --- | --- |
| ts_code | str | TS指数代码 |
| trade_date | str | 交易日 |
| close | float | 收盘点位 |
| open | float | 开盘点位 |
| high | float | 最高点位 |
| low | float | 最低点位 |
| pre_close | float | 昨日收盘点 |
| change | float | 涨跌点 |
| pct_chg | float | 涨跌幅（%） |
| vol | float | 成交量（手） |
| amount | float | 成交额（千元） |







接口使用

```python
pro = ts.pro_api()

df = pro.index_daily(ts_code='399300.SZ')

#或者按日期取

df = pro.index_daily(ts_code='399300.SZ', start_date='20180101', end_date='20181010')
```







数据样例

```python
ts_code trade_date      close       open       high        low  \
0     399300.SZ   20180903  3321.8248  3320.6898  3325.6070  3291.7842   
```